﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Microsoft.Practices.Composite.Events;
using PrismEvent.Infrastructure;
using Microsoft.Practices.Composite.Presentation.Events;

namespace PrismEvent.Subscriber
{
    /// <summary>
    /// Interaction logic for SubscriberView.xaml
    /// </summary>
    public partial class SubscriberView : UserControl
    {
        IEventAggregator eventAggregator;
        private SubscriptionToken subscriptionToken;

        public SubscriberView()
        {
            InitializeComponent();
        }

        public SubscriberView(IEventAggregator eventAggregator)
            : this()
        {
            this.eventAggregator = eventAggregator;

            //subscribe a method with a simple type parameters
            //subscribe two times
            this.eventAggregator.GetEvent<MessageAddedEvent>().Subscribe(ShowMessageBox);
            this.eventAggregator.GetEvent<MessageAddedEvent>().Subscribe(ShowMessage);

            //subscribe a method with a composite type parameters
            this.eventAggregator.GetEvent<NewsAddedEvent>().Subscribe(ShowMessage);

            //subscribe a method without parameters
            this.eventAggregator.GetEvent<NullableEvent>().Subscribe(DoSomething);

            //standard coding format for event
            StandardMessageAddedEvent messageAddedEvent = eventAggregator.GetEvent<StandardMessageAddedEvent>();

            if (subscriptionToken != null)
            {
                messageAddedEvent.Unsubscribe(subscriptionToken);
            }

            subscriptionToken = messageAddedEvent.Subscribe(ShowMessage2, ThreadOption.UIThread, true, Filter);

        }

        public void ShowMessage(string text)
        {
            tbSimpleParam.Text = text;
        }

        public void ShowMessage2(string text)
        {
            tbSimpleParam.Text = text;

            StandardMessageAddedEvent messageAddedEvent = eventAggregator.GetEvent<StandardMessageAddedEvent>();
            if (subscriptionToken != null)
            {
                messageAddedEvent.Unsubscribe(subscriptionToken);
            }
        }

        public void ShowMessage(News news)
        {
            tbSimpleParam.Text = news.Title;
        }

        public void ShowMessageBox(string text)
        {
            MessageBox.Show(text);
        }

        public void DoSomething(NullClass nullClass)
        {
            //Do Something();
        }

        public bool Filter(string text)
        {
            return true;
            //return false;
        }
    }
}